@@ -65,8 +65,6 @@ extern unsigned long max_debug_file_size;
 FILE            *debug_file_fp = NULL;
 static FILE	*log_fp;
 
-int dummy;	/* reduce compiler warnings */
-
 static pthread_mutex_t debug_fp_lock;
 
 /*
@@ -188,27 +186,36 @@ void logit(int data_type, int display, const char *fmt, ...) {
 
 /* write something to the log file and syslog facility */
 int write_to_all_logs(char *buffer, unsigned long data_type) {
+	return write_to_all_logs_with_host_service(buffer, data_type, NULL, NULL);
+}
+
+int write_to_all_logs_with_host_service(char *buffer, unsigned long data_type, host *hst, service *svc) {
 
 	/* write to syslog */
 	write_to_syslog(buffer, data_type);
 
 	/* write to main log */
-	write_to_log(buffer, data_type, NULL);
+	write_to_log_with_host_service(buffer, data_type, NULL, hst, svc);
 
 	return OK;
 }
 
 
 /* write something to the log file and syslog facility */
-static void write_to_all_logs_with_timestamp(char *buffer, unsigned long data_type, time_t *timestamp) {
+static void write_to_all_logs_with_timestamp_with_host_service(char *buffer, unsigned long data_type, time_t *timestamp, host *hst, service *svc) {
 
 	/* write to syslog */
 	write_to_syslog(buffer, data_type);
 
 	/* write to main log */
-	write_to_log(buffer, data_type, timestamp);
+	write_to_log_with_host_service(buffer, data_type, timestamp, hst, svc);
 }
 
+static void write_to_all_logs_with_timestamp(char *buffer, unsigned long data_type, time_t *timestamp) {
+	write_to_all_logs_with_timestamp_with_host_service(buffer, data_type, timestamp, NULL, NULL);
+}
+
+
 FILE *open_log_file(void) {
 
 	if (log_fp) /* keep it open unless we rotate */
@@ -262,6 +269,10 @@ int close_log_file(void) {
 
 /* write something to the icinga log file */
 int write_to_log(char *buffer, unsigned long data_type, time_t *timestamp) {
+	return write_to_log_with_host_service(buffer, data_type, timestamp, NULL, NULL);
+}
+
+int write_to_log_with_host_service(char *buffer, unsigned long data_type, time_t *timestamp, host *hst, service *svc) {
 	FILE *fp;
 	time_t log_time = 0L;
 
@@ -300,7 +311,7 @@ int write_to_log(char *buffer, unsigned long data_type, time_t *timestamp) {
 
 #ifdef USE_EVENT_BROKER
 	/* send data to the event broker */
-	broker_log_data(NEBTYPE_LOG_DATA, NEBFLAG_NONE, NEBATTR_NONE, buffer, data_type, log_time, NULL);
+	broker_log_data_with_host_service(NEBTYPE_LOG_DATA, NEBFLAG_NONE, NEBATTR_NONE, buffer, data_type, log_time, NULL, hst, svc);
 #endif
 
 	return OK;
@@ -389,7 +400,7 @@ int log_service_event(service *svc) {
 
 	/* either log only the output, or if enabled, add long_output */
 	if (log_long_plugin_output == TRUE && svc->long_plugin_output != NULL) {
-		dummy = asprintf(&temp_buffer, "SERVICE ALERT: %s;%s;%s;%s;%d;%s\\n%s\n",
+		asprintf(&temp_buffer, "SERVICE ALERT: %s;%s;%s;%s;%d;%s\\n%s\n",
 				svc->host_name, svc->description,
 				service_state_name(svc->current_state),
 				state_type_name(svc->state_type),
@@ -398,7 +409,7 @@ int log_service_event(service *svc) {
 				svc->long_plugin_output
 				);
 	} else {
-		dummy = asprintf(&temp_buffer, "SERVICE ALERT: %s;%s;%s;%s;%d;%s\n",
+		asprintf(&temp_buffer, "SERVICE ALERT: %s;%s;%s;%s;%d;%s\n",
 				svc->host_name, svc->description,
 				service_state_name(svc->current_state),
 				state_type_name(svc->state_type),
@@ -407,7 +418,7 @@ int log_service_event(service *svc) {
 				);
 	}
 
-	write_to_all_logs(temp_buffer, log_options);
+	write_to_all_logs_with_host_service(temp_buffer, log_options, temp_host, svc);
 	my_free(temp_buffer);
 
 	return OK;
@@ -429,7 +440,7 @@ int log_host_event(host *hst) {
 
 	/* either log only the output, or if enabled, add long_output */
 	if (log_long_plugin_output == TRUE && hst->long_plugin_output != NULL) {
-		dummy = asprintf(&temp_buffer, "HOST ALERT: %s;%s;%s;%d;%s\\n%s\n",
+		asprintf(&temp_buffer, "HOST ALERT: %s;%s;%s;%d;%s\\n%s\n",
 				hst->name,
 				host_state_name(hst->current_state),
 				state_type_name(hst->state_type),
@@ -438,7 +449,7 @@ int log_host_event(host *hst) {
 				hst->long_plugin_output
 				);
 	} else {
-		dummy = asprintf(&temp_buffer, "HOST ALERT: %s;%s;%s;%d;%s\n",
+		asprintf(&temp_buffer, "HOST ALERT: %s;%s;%s;%d;%s\n",
 				hst->name,
 				host_state_name(hst->current_state),
 				state_type_name(hst->state_type),
@@ -447,7 +458,7 @@ int log_host_event(host *hst) {
 				);
 	}
 
-	write_to_all_logs(temp_buffer, log_options);
+	write_to_all_logs_with_host_service(temp_buffer, log_options, hst, NULL);
 	my_free(temp_buffer);
 
 	return OK;
@@ -465,7 +476,7 @@ int log_host_states(int type, time_t *timestamp) {
 
 	for (temp_host = host_list; temp_host != NULL; temp_host = temp_host->next) {
 
-		dummy = asprintf(&temp_buffer, "%s HOST STATE: %s;%s;%s;%d;%s\n",
+		asprintf(&temp_buffer, "%s HOST STATE: %s;%s;%s;%d;%s\n",
 				(type == INITIAL_STATES) ? "INITIAL" : "CURRENT",
 				temp_host->name,
 				host_state_name(temp_host->current_state),
@@ -474,7 +485,7 @@ int log_host_states(int type, time_t *timestamp) {
 				(temp_host->plugin_output == NULL) ? "" : temp_host->plugin_output
 				);
 
-		write_to_all_logs_with_timestamp(temp_buffer, NSLOG_INFO_MESSAGE, timestamp);
+		write_to_all_logs_with_timestamp_with_host_service(temp_buffer, NSLOG_INFO_MESSAGE, timestamp, temp_host, NULL);
 
 		my_free(temp_buffer);
 	}
@@ -499,7 +510,7 @@ int log_service_states(int type, time_t *timestamp) {
 		if ((temp_host = temp_service->host_ptr) == NULL)
 			continue;
 
-		dummy = asprintf(&temp_buffer, "%s SERVICE STATE: %s;%s;%s;%s;%d;%s\n",
+		asprintf(&temp_buffer, "%s SERVICE STATE: %s;%s;%s;%s;%d;%s\n",
 				(type == INITIAL_STATES) ? "INITIAL" : "CURRENT",
 				temp_service->host_name,
 				temp_service->description,
@@ -509,7 +520,7 @@ int log_service_states(int type, time_t *timestamp) {
 				temp_service->plugin_output
 				);
 
-		write_to_all_logs_with_timestamp(temp_buffer, NSLOG_INFO_MESSAGE, timestamp);
+		write_to_all_logs_with_timestamp_with_host_service(temp_buffer, NSLOG_INFO_MESSAGE, timestamp, temp_host, temp_service);
 
 		my_free(temp_buffer);
 	}
@@ -552,7 +563,7 @@ int rotate_log_file(time_t rotation_time) {
 	close_log_file();
 
 	/* get the archived filename to use */
-	dummy = asprintf(&log_archive, "%s%sicinga-%02d-%02d-%d-%02d.log", log_archive_path, (log_archive_path[strlen(log_archive_path)-1] == '/') ? "" : "/", t->tm_mon + 1, t->tm_mday, t->tm_year + 1900, t->tm_hour);
+	asprintf(&log_archive, "%s%sicinga-%02d-%02d-%d-%02d.log", log_archive_path, (log_archive_path[strlen(log_archive_path)-1] == '/') ? "" : "/", t->tm_mon + 1, t->tm_mday, t->tm_year + 1900, t->tm_hour);
 
 	/* rotate the log file */
 	rename_result = my_rename(log_file, log_archive);
@@ -565,7 +576,7 @@ int rotate_log_file(time_t rotation_time) {
 	}
 
 	/* record the log rotation after it has been done... */
-	dummy = asprintf(&temp_buffer, "LOG ROTATION: %s\n", method_string);
+	asprintf(&temp_buffer, "LOG ROTATION: %s\n", method_string);
 	write_to_all_logs_with_timestamp(temp_buffer, NSLOG_PROCESS_INFO, &rotation_time);
 	my_free(temp_buffer);
 
@@ -574,7 +585,7 @@ int rotate_log_file(time_t rotation_time) {
 
 	if (stat_result == 0) {
 		chmod(log_file, log_file_stat.st_mode);
-		dummy = chown(log_file, log_file_stat.st_uid, log_file_stat.st_gid);
+		chown(log_file, log_file_stat.st_uid, log_file_stat.st_gid);
 	}
 
 	/* log current host and service state if activated*/
@@ -595,7 +606,7 @@ int write_log_file_info(time_t *timestamp) {
 	char *temp_buffer = NULL;
 
 	/* write log version */
-	dummy = asprintf(&temp_buffer, "LOG VERSION: %s\n", LOG_VERSION_2);
+	asprintf(&temp_buffer, "LOG VERSION: %s\n", LOG_VERSION_2);
 	write_to_all_logs_with_timestamp(temp_buffer, NSLOG_PROCESS_INFO, timestamp);
 	my_free(temp_buffer);
 
@@ -633,6 +644,18 @@ int close_debug_log(void) {
 	return OK;
 }
 
+/* returns TRUE if logging applies
+ * TRUE=1 so can do 'if(log_level(...)) {' for conditional debugging
+ */
+int log_level(int level, int verbosity) {
+	if (!(debug_level == DEBUGL_ALL || (level & debug_level)))
+		return FALSE;
+
+	if (verbosity > debug_verbosity)
+		return FALSE;
+
+	return TRUE;
+}
 
 /* write to the debug log */
 int log_debug_info(int level, int verbosity, const char *fmt, ...) {
@@ -640,10 +663,8 @@ int log_debug_info(int level, int verbosity, const char *fmt, ...) {
 	char *temp_path = NULL;
 	struct timeval current_time;
 
-	if (!(debug_level == DEBUGL_ALL || (level & debug_level)))
-		return OK;
-
-	if (verbosity > debug_verbosity)
+	/* ignore if logging is not appropriate */
+	if (log_level(level, verbosity) != TRUE)
 		return OK;
 
 	if (debug_file_fp == NULL)
@@ -677,7 +698,7 @@ int log_debug_info(int level, int verbosity, const char *fmt, ...) {
 		close_debug_log();
 
 		/* rotate the log file */
-		dummy = asprintf(&temp_path, "%s.old", debug_file);
+		asprintf(&temp_path, "%s.old", debug_file);
 		if (temp_path) {
 
 			/* unlink the old debug file */
