@@ -62,8 +62,6 @@ extern command         *ochp_command_ptr;
 
 extern time_t          program_start;
 
-int dummy;	/* reduce compiler warnings */
-
 /******************************************************************/
 /************* OBSESSIVE COMPULSIVE HANDLER FUNCTIONS *************/
 /******************************************************************/
@@ -308,7 +306,7 @@ int run_global_service_event_handler(icinga_macros *mac, service *svc) {
 	log_debug_info(DEBUGL_EVENTHANDLERS, 2, "Processed global service event handler command line: %s\n", processed_command);
 
 	if (log_event_handlers == TRUE) {
-		dummy = asprintf(&raw_logentry, "GLOBAL SERVICE EVENT HANDLER: %s;%s;$SERVICESTATE$;$SERVICESTATETYPE$;$SERVICEATTEMPT$;%s\n", svc->host_name, svc->description, global_service_event_handler);
+		asprintf(&raw_logentry, "GLOBAL SERVICE EVENT HANDLER: %s;%s;$SERVICESTATE$;$SERVICESTATETYPE$;$SERVICEATTEMPT$;%s\n", svc->host_name, svc->description, global_service_event_handler);
 		process_macros_r(mac, raw_logentry, &processed_logentry, macro_options);
 		logit(NSLOG_EVENT_HANDLER, FALSE, "%s", processed_logentry);
 	}
@@ -406,7 +404,7 @@ int run_service_event_handler(icinga_macros *mac, service *svc) {
 	log_debug_info(DEBUGL_EVENTHANDLERS, 2, "Processed service event handler command line: %s\n", processed_command);
 
 	if (log_event_handlers == TRUE) {
-		dummy = asprintf(&raw_logentry, "SERVICE EVENT HANDLER: %s;%s;$SERVICESTATE$;$SERVICESTATETYPE$;$SERVICEATTEMPT$;%s\n", svc->host_name, svc->description, svc->event_handler);
+		asprintf(&raw_logentry, "SERVICE EVENT HANDLER: %s;%s;$SERVICESTATE$;$SERVICESTATETYPE$;$SERVICEATTEMPT$;%s\n", svc->host_name, svc->description, svc->event_handler);
 		process_macros_r(mac, raw_logentry, &processed_logentry, macro_options);
 		logit(NSLOG_EVENT_HANDLER, FALSE, "%s", processed_logentry);
 	}
@@ -552,7 +550,7 @@ int run_global_host_event_handler(icinga_macros *mac, host *hst) {
 	log_debug_info(DEBUGL_EVENTHANDLERS, 2, "Processed global host event handler command line: %s\n", processed_command);
 
 	if (log_event_handlers == TRUE) {
-		dummy = asprintf(&raw_logentry, "GLOBAL HOST EVENT HANDLER: %s;$HOSTSTATE$;$HOSTSTATETYPE$;$HOSTATTEMPT$;%s\n", hst->name, global_host_event_handler);
+		asprintf(&raw_logentry, "GLOBAL HOST EVENT HANDLER: %s;$HOSTSTATE$;$HOSTSTATETYPE$;$HOSTATTEMPT$;%s\n", hst->name, global_host_event_handler);
 		process_macros_r(mac, raw_logentry, &processed_logentry, macro_options);
 		logit(NSLOG_EVENT_HANDLER, FALSE, "%s", processed_logentry);
 	}
@@ -649,7 +647,7 @@ int run_host_event_handler(icinga_macros *mac, host *hst) {
 	log_debug_info(DEBUGL_EVENTHANDLERS, 2, "Processed host event handler command line: %s\n", processed_command);
 
 	if (log_event_handlers == TRUE) {
-		dummy = asprintf(&raw_logentry, "HOST EVENT HANDLER: %s;$HOSTSTATE$;$HOSTSTATETYPE$;$HOSTATTEMPT$;%s\n", hst->name, hst->event_handler);
+		asprintf(&raw_logentry, "HOST EVENT HANDLER: %s;$HOSTSTATE$;$HOSTSTATETYPE$;$HOSTATTEMPT$;%s\n", hst->name, hst->event_handler);
 		process_macros_r(mac, raw_logentry, &processed_logentry, macro_options);
 		logit(NSLOG_EVENT_HANDLER, FALSE, "%s", processed_logentry);
 	}
