@@ -3,7 +3,7 @@
  * GETCGI.C -  Icinga CGI Input Routines
  *
  * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
- * Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2013 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  *****************************************************************************/
 
@@ -109,15 +109,27 @@ void unescape_cgi_input(char *input) {
 	len = strlen(input);
 	for (x = 0, y = 0; x < len; x++, y++) {
 
-		if (input[x] == '\x0')
+		if (input[x] == '\x0') {
 			break;
-		else if (input[x] == '%') {
+
+		// RB 2013-04-07
+		// only allow hex conversion if '%' is follow by a valid character
+		} else if (input[x] == '%' && (
+			// 0 - 9
+			(input[x+1] >= 48 && input[x+1] <= 57) ||
+			// A - F
+			(input[x+1] >= 65 && input[x+1] <= 70) ||
+			// a - f
+			(input[x+1] >= 97 && input[x+1] <= 102))
+			) {
+
 			input[y] = hex_to_char(&input[x+1]);
 			x += 2;
+
 		// RB 2011-09-08
 		// convert plus as well that it can bu used in service and host names
 		} else if (input[x] == '+') {
-				input[y] = ' ';
+			input[y] = ' ';
 		} else
 			input[y] = input[x];
 	}
@@ -157,13 +169,16 @@ char **getcgivars(void) {
 		/* check for NULL query string environment variable - 04/28/00 (Ludo Bosmans) */
 		if (getenv("QUERY_STRING") == NULL) {
 			cgiinput = (char *)malloc(1);
+			if (cgiinput != NULL) {
+				cgiinput[0] = '\x0';
+			}
+		} else {
+			cgiinput = strdup(getenv("QUERY_STRING"));
 			if (cgiinput == NULL) {
 				printf("getcgivars(): Could not allocate memory for CGI input.\n");
 				exit(1);
 			}
-			cgiinput[0] = '\x0';
-		} else
-			cgiinput = strdup(getenv("QUERY_STRING"));
+		}
 	}
 
 	else if (!strcmp(request_method, "POST") || !strcmp(request_method, "PUT")) {
@@ -203,6 +218,7 @@ char **getcgivars(void) {
 			exit(1);
 		}
 		cgiinput[content_length] = '\0';
+
 	} else {
 
 		printf("getcgivars(): Unsupported REQUEST_METHOD -> '%s'\n", request_method);
@@ -232,7 +248,11 @@ char **getcgivars(void) {
 	paircount = 0;
 	nvpair = strtok(cgiinput, "&");
 	while (nvpair) {
-		pairlist[paircount++] = strdup(nvpair);
+		pairlist[paircount] = strdup(nvpair);
+		if(pairlist[paircount++] == NULL) {
+			printf("getcgivars(): Could not allocate memory for name-value pair element #%d.\n", paircount);
+			exit(1);
+		}
 		if (paircount > MAX_CGI_INPUT_PAIRS)
 			break;
 		if (!(paircount % 256)) {
@@ -254,17 +274,34 @@ char **getcgivars(void) {
 		printf("getcgivars(): Could not allocate memory for name-value list.\n");
 		exit(1);
 	}
+
 	for (i = 0; i < paircount; i++) {
 
 		/* get the variable name preceding the equal (=) sign */
 		if ((eqpos = strchr(pairlist[i], '=')) != NULL) {
 			*eqpos = '\0';
-			unescape_cgi_input(cgivars[i*2+1] = strdup(eqpos + 1));
-		} else
-			unescape_cgi_input(cgivars[i*2+1] = strdup(""));
+			cgivars[i*2+1] = strdup(eqpos + 1);
+			if(cgivars[i*2+1] == NULL) {
+				printf("getcgivars(): Could not allocate memory for cgi param value #%d.\n", i);
+				exit(1);
+			}
+			unescape_cgi_input(cgivars[i*2+1]);
+
+		} else {
+			cgivars[i*2+1] = strdup("");
+			if(cgivars[i*2+1] == NULL) {
+				printf("getcgivars(): Could not allocate memory for empty cgi param value #%d.\n", i);
+				exit(1);
+			}
+		}
 
 		/* get the variable value (or name/value of there was no real "pair" in the first place) */
-		unescape_cgi_input(cgivars[i*2] = strdup(pairlist[i]));
+		cgivars[i*2] = strdup(pairlist[i]);
+		if(cgivars[i*2] == NULL) {
+			printf("getcgivars(): Could not allocate memory for cgi param name #%d.\n", i);
+			exit(1);
+		}
+		unescape_cgi_input(cgivars[i*2]);
 	}
 
 	/* terminate the name-value list */
