@@ -60,8 +60,6 @@ servicestatus   **servicestatus_hashlist = NULL;
 extern int      use_pending_states;
 #endif
 
-int dummy;	/* reduce compiler warnings */
-
 #ifdef NSCORE
 
 /******************************************************************/
@@ -348,12 +346,12 @@ int add_host_status(hoststatus *new_hoststatus) {
 			my_free(new_hoststatus->plugin_output);
 			if (new_hoststatus->should_be_scheduled == TRUE) {
 				get_time_string(&new_hoststatus->next_check, date_string, sizeof(date_string), LONG_DATE_TIME);
-				dummy = asprintf(&new_hoststatus->plugin_output, "Host check scheduled for %s", date_string);
+				asprintf(&new_hoststatus->plugin_output, "Host check scheduled for %s", date_string);
 			} else {
 				/* passive-only hosts that have just been scheduled for a forced check */
 				if (new_hoststatus->checks_enabled == FALSE && new_hoststatus->next_check != (time_t)0L && (new_hoststatus->check_options & CHECK_OPTION_FORCE_EXECUTION)) {
 					get_time_string(&new_hoststatus->next_check, date_string, sizeof(date_string), LONG_DATE_TIME);
-					dummy = asprintf(&new_hoststatus->plugin_output, "Forced host check scheduled for %s", date_string);
+					asprintf(&new_hoststatus->plugin_output, "Forced host check scheduled for %s", date_string);
 				}
 				/* passive-only hosts not scheduled to be checked */
 				else
@@ -418,12 +416,12 @@ int add_service_status(servicestatus *new_svcstatus) {
 			my_free(new_svcstatus->plugin_output);
 			if (new_svcstatus->should_be_scheduled == TRUE) {
 				get_time_string(&new_svcstatus->next_check, date_string, sizeof(date_string), LONG_DATE_TIME);
-				dummy = asprintf(&new_svcstatus->plugin_output, "Service check scheduled for %s", date_string);
+				asprintf(&new_svcstatus->plugin_output, "Service check scheduled for %s", date_string);
 			} else {
 				/* passive-only services that have just been scheduled for a forced check */
 				if (new_svcstatus->checks_enabled == FALSE && new_svcstatus->next_check != (time_t)0L && (new_svcstatus->check_options & CHECK_OPTION_FORCE_EXECUTION)) {
 					get_time_string(&new_svcstatus->next_check, date_string, sizeof(date_string), LONG_DATE_TIME);
-					dummy = asprintf(&new_svcstatus->plugin_output, "Forced service check scheduled for %s", date_string);
+					asprintf(&new_svcstatus->plugin_output, "Forced service check scheduled for %s", date_string);
 				}
 				/* passive-only services not scheduled to be checked */
 				else
@@ -474,6 +472,7 @@ void free_status_data(void) {
 		my_free(this_hoststatus->plugin_output);
 		my_free(this_hoststatus->long_plugin_output);
 		my_free(this_hoststatus->perf_data);
+		my_free(this_hoststatus->check_source);
 		my_free(this_hoststatus);
 	}
 
@@ -485,6 +484,7 @@ void free_status_data(void) {
 		my_free(this_svcstatus->plugin_output);
 		my_free(this_svcstatus->long_plugin_output);
 		my_free(this_svcstatus->perf_data);
+		my_free(this_svcstatus->check_source);
 		my_free(this_svcstatus);
 	}
 
