@@ -3,7 +3,7 @@
  * CGIAUTH.H - Authorization utilities header file
  *
  * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
- * Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2013 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  *****************************************************************************/
 
@@ -44,6 +44,8 @@ typedef struct authdata_struct{
 	int authorized_for_configuration_information;
 	int authorized_for_full_command_resolution;
 	int authorized_for_read_only;
+	int authorized_for_comments_read_only;
+	int authorized_for_downtimes_read_only;
 	int authenticated;
 	int number_of_authentication_rules;
 	char **authentication_rules;
@@ -77,6 +79,9 @@ int is_authorized_for_configuration_information(authdata *);
 int is_authorized_for_full_command_resolution(authdata *);
 
 int is_authorized_for_read_only(authdata *);
+int is_authorized_for_comments_read_only(authdata *);
+int is_authorized_for_downtimes_read_only(authdata *);
+
 #ifdef __cplusplus
   }
 #endif
