@@ -112,10 +112,12 @@ extern "C" {
 /**************************** JAVASCRIPT NAMES ******************************/
 
 #define CHECKBOX_FUNCTIONS_JS   "checkbox_functions.js"
+#define COMMON_FUNCTIONS_JS	"common_functions.js"
 #define JQUERY_MAIN_JS		"jquery-1.8.0.min.js"
 #define JQUERY_DD_JS		"jquery.dd.js"
 #define SKINNYTIP_JS		"skinnytip.js"
 #define PAGE_REFRESH_JS		"page_refresh.js"
+#define STATUS_FILTER_JS	"status_filter_functions.js"
 
 
 /**************************** JQUERY-UI PATH ******************************/
@@ -125,6 +127,9 @@ extern "C" {
 #define JQ_UI_MOUSE_JS		"ui/jquery.ui.mouse.js"
 #define JQ_UI_SLIDER_JS		"ui/jquery.ui.slider.js"
 #define JQ_UI_DATEPICKER_JS	"ui/jquery.ui.datepicker.js"
+#define JQ_UI_EFFECT_JS		"ui/jquery.ui.effect.js"
+#define JQ_UI_EFFECT_BLIND_JS	"ui/jquery.ui.effect-blind.js"
+#define JQ_UI_BUTTON_JS		"ui/jquery.ui.button.js"
 #define JQ_UI_TIMEPICKER_JS	"jquery.ui.timepicker-addon.min.js"
 
 #define JQ_UI_ALL_CSS		"themes/base/jquery.ui.all.css"
@@ -360,6 +365,10 @@ extern "C" {
 
 /****************** HOST AND SERVICE FILTER PROPERTIES  *******************/
 
+/*
+	Changes here must be represented in "html/js/status_filter_functions.js"
+*/
+
 #define HOST_SCHEDULED_DOWNTIME		1
 #define HOST_NO_SCHEDULED_DOWNTIME	2
 #define HOST_STATE_ACKNOWLEDGED		4
@@ -376,8 +385,8 @@ extern "C" {
 #define HOST_NOTIFICATIONS_ENABLED	8192
 #define HOST_PASSIVE_CHECKS_DISABLED	16384
 #define HOST_PASSIVE_CHECKS_ENABLED	32768
-#define HOST_PASSIVE_CHECK		65536
-#define HOST_ACTIVE_CHECK		131072
+//#define HOST_PASSIVE_CHECK		65536		/* unused, no idea why it got implented in first place */
+//#define HOST_ACTIVE_CHECK		131072		/* unused, no idea why it got implented in first place */
 #define HOST_HARD_STATE			262144
 #define HOST_SOFT_STATE			524288
 #define HOST_STATE_HANDLED		1048576
@@ -400,8 +409,8 @@ extern "C" {
 #define SERVICE_NOTIFICATIONS_ENABLED	8192
 #define SERVICE_PASSIVE_CHECKS_DISABLED	16384
 #define SERVICE_PASSIVE_CHECKS_ENABLED	32768
-#define SERVICE_PASSIVE_CHECK		65536
-#define SERVICE_ACTIVE_CHECK		131072
+//#define SERVICE_PASSIVE_CHECK		65536		/* unused, no idea why it got implented in first place */
+//#define SERVICE_ACTIVE_CHECK		131072		/* unused, no idea why it got implented in first place */
 #define SERVICE_HARD_STATE		262144
 #define SERVICE_SOFT_STATE		524288
 #define SERVICE_STATE_HANDLED		1048576
@@ -439,7 +448,7 @@ extern "C" {
 
 /************************** JSON OUTPUT VERSION ************************/
 
-#define JSON_OUTPUT_VERSION "1.9.0"
+#define JSON_OUTPUT_VERSION "1.10.0"
 
 
 /************************** BUFFER  ***************************************/
@@ -517,6 +526,8 @@ extern "C" {
 
 /******************************** FUNCTIONS *******************************/
 
+int check_exclude_customvar(customvariablesmember *);
+
 void reset_cgi_vars(void);
 void free_memory(void);
 
