@@ -101,6 +101,8 @@ int log_debug_info(int,int,const char *,...)
 #endif /* gnu */
 
 #ifndef NSCGI
+int write_to_all_logs_with_host_service(char *, unsigned long, host *, service *);
+int write_to_log_with_host_service(char *, unsigned long, time_t *, host *, service *);
 int write_to_all_logs(char *,unsigned long);            /* writes a string to main log file and syslog facility */
 int write_to_log(char *,unsigned long,time_t *);       	/* write a string to the main log file */
 int write_to_syslog(char *,unsigned long);             	/* write a string to the syslog facility */
@@ -115,6 +117,7 @@ int close_debug_log(void);
 FILE *open_log_file(void);
 int close_log_file(void);
 int fix_log_file_owner(uid_t, gid_t);
+int log_level(int, int);
 
 #endif /* !NSCGI */
 
