@@ -83,7 +83,7 @@ CREATE TABLE IF NOT EXISTS icinga_commenthistory (
   deletion_time timestamp  default '0000-00-00 00:00:00',
   deletion_time_usec  int default 0,
   PRIMARY KEY  (commenthistory_id),
-  UNIQUE KEY instance_id (instance_id,comment_time,internal_comment_id)
+  UNIQUE KEY instance_id (instance_id,object_id,comment_time,internal_comment_id)
 ) ENGINE=InnoDB  COMMENT='Historical host and service comments';
 
 -- --------------------------------------------------------
@@ -109,7 +109,7 @@ CREATE TABLE IF NOT EXISTS icinga_comments (
   expires smallint default 0,
   expiration_time timestamp  default '0000-00-00 00:00:00',
   PRIMARY KEY  (comment_id),
-  UNIQUE KEY instance_id (instance_id,comment_time,internal_comment_id)
+  UNIQUE KEY instance_id (instance_id,object_id,comment_time,internal_comment_id)
 ) ENGINE=InnoDB  COMMENT='Usercomments on Icinga objects';
 
 -- --------------------------------------------------------
@@ -396,7 +396,7 @@ CREATE TABLE IF NOT EXISTS icinga_downtimehistory (
   internal_downtime_id bigint unsigned default 0,
   triggered_by_id bigint unsigned default 0,
   is_fixed smallint default 0,
-  duration smallint default 0,
+  duration bigint(20) default 0,
   scheduled_start_time timestamp  default '0000-00-00 00:00:00',
   scheduled_end_time timestamp  default '0000-00-00 00:00:00',
   was_started smallint default 0,
@@ -703,6 +703,7 @@ CREATE TABLE IF NOT EXISTS icinga_hoststatus (
   output TEXT character set latin1  default '',
   long_output TEXT  default '',
   perfdata TEXT character set latin1  default '',
+  check_source TEXT character set latin1  default '',
   current_state smallint default 0,
   has_been_checked smallint default 0,
   should_be_scheduled smallint default 0,
@@ -818,6 +819,7 @@ CREATE TABLE IF NOT EXISTS icinga_logentries (
   logentry_data TEXT character set latin1  default '',
   realtime_data smallint default 0,
   inferred_data_extracted smallint default 0,
+  object_id bigint unsigned default NULL,
   PRIMARY KEY  (logentry_id)
 ) ENGINE=InnoDB COMMENT='Historical record of log entries';
 
@@ -950,7 +952,7 @@ CREATE TABLE IF NOT EXISTS icinga_scheduleddowntime (
   internal_downtime_id bigint unsigned default 0,
   triggered_by_id bigint unsigned default 0,
   is_fixed smallint default 0,
-  duration smallint default 0,
+  duration bigint(20) default 0,
   scheduled_start_time timestamp  default '0000-00-00 00:00:00',
   scheduled_end_time timestamp  default '0000-00-00 00:00:00',
   was_started smallint default 0,
@@ -1179,6 +1181,7 @@ CREATE TABLE IF NOT EXISTS icinga_servicestatus (
   output TEXT character set latin1  default '',
   long_output TEXT  default '',
   perfdata TEXT character set latin1  default '',
+  check_source TEXT character set latin1  default '',
   current_state smallint default 0,
   has_been_checked smallint default 0,
   should_be_scheduled smallint default 0,
@@ -1302,48 +1305,6 @@ CREATE TABLE IF NOT EXISTS icinga_systemcommands (
 
 -- --------------------------------------------------------
 
---
--- Table structure for table icinga_timedeventqueue
---
-
-CREATE TABLE IF NOT EXISTS icinga_timedeventqueue (
-  timedeventqueue_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
-  instance_id bigint unsigned default 0,
-  event_type smallint default 0,
-  queued_time timestamp  default '0000-00-00 00:00:00',
-  queued_time_usec  int default 0,
-  scheduled_time timestamp  default '0000-00-00 00:00:00',
-  recurring_event smallint default 0,
-  object_id bigint unsigned default 0,
-  PRIMARY KEY  (timedeventqueue_id),
-  UNIQUE KEY instance_id (instance_id,event_type,scheduled_time,object_id)
-) ENGINE=InnoDB  COMMENT='Current Icinga event queue';
-
--- --------------------------------------------------------
-
---
--- Table structure for table icinga_timedevents
---
-
-CREATE TABLE IF NOT EXISTS icinga_timedevents (
-  timedevent_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
-  instance_id bigint unsigned default 0,
-  event_type smallint default 0,
-  queued_time timestamp  default '0000-00-00 00:00:00',
-  queued_time_usec  int default 0,
-  event_time timestamp  default '0000-00-00 00:00:00',
-  event_time_usec  int default 0,
-  scheduled_time timestamp  default '0000-00-00 00:00:00',
-  recurring_event smallint default 0,
-  object_id bigint unsigned default 0,
-  deletion_time timestamp  default '0000-00-00 00:00:00',
-  deletion_time_usec  int default 0,
-  PRIMARY KEY  (timedevent_id),
-  UNIQUE KEY instance_id (instance_id,event_type,scheduled_time,object_id)
-) ENGINE=InnoDB  COMMENT='Historical events from the Icinga event queue';
-
--- --------------------------------------------------------
-
 --
 -- Table structure for table icinga_timeperiods
 --
@@ -1374,25 +1335,6 @@ CREATE TABLE IF NOT EXISTS icinga_timeperiod_timeranges (
   PRIMARY KEY  (timeperiod_timerange_id)
 ) ENGINE=InnoDB  COMMENT='Timeperiod definitions';
 
--- --------------------------------------------------------
-
---
--- Table structure for table icinga_slahistory
---
-
-CREATE TABLE IF NOT EXISTS icinga_slahistory (
-  slahistory_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
-  instance_id bigint unsigned default 0,
-  start_time timestamp null default NULL,
-  end_time timestamp null default NULL,
-  acknowledgement_time timestamp null default NULL,
-  object_id bigint unsigned default 0,
-  state smallint default 0,
-  state_type smallint default '0',
-  scheduled_downtime tinyint(1) default 0,
-  PRIMARY KEY (slahistory_id)
-) ENGINE=InnoDB COMMENT='SLA statehistory';
-
 
 -- -----------------------------------------
 -- add index (delete)
@@ -1400,13 +1342,10 @@ CREATE TABLE IF NOT EXISTS icinga_slahistory (
 
 -- for periodic delete 
 -- instance_id and
--- TIMEDEVENTS => scheduled_time
 -- SYSTEMCOMMANDS, SERVICECHECKS, HOSTCHECKS, EVENTHANDLERS  => start_time
 -- EXTERNALCOMMANDS => entry_time
 
 -- instance_id
-CREATE INDEX timedevents_i_id_idx on icinga_timedevents(instance_id);
-CREATE INDEX timedeventq_i_id_idx on icinga_timedeventqueue(instance_id);
 CREATE INDEX systemcommands_i_id_idx on icinga_systemcommands(instance_id);
 CREATE INDEX servicechecks_i_id_idx on icinga_servicechecks(instance_id);
 CREATE INDEX hostchecks_i_id_idx on icinga_hostchecks(instance_id);
@@ -1414,8 +1353,6 @@ CREATE INDEX eventhandlers_i_id_idx on icinga_eventhandlers(instance_id);
 CREATE INDEX externalcommands_i_id_idx on icinga_externalcommands(instance_id);
 
 -- time
-CREATE INDEX timedevents_time_id_idx on icinga_timedevents(scheduled_time);
-CREATE INDEX timedeventq_time_id_idx on icinga_timedeventqueue(scheduled_time);
 CREATE INDEX systemcommands_time_id_idx on icinga_systemcommands(start_time);
 CREATE INDEX servicechecks_time_id_idx on icinga_servicechecks(start_time);
 CREATE INDEX hostchecks_time_id_idx on icinga_hostchecks(start_time);
@@ -1431,7 +1368,6 @@ CREATE INDEX programstatus_i_id_idx on icinga_programstatus(instance_id);
 CREATE INDEX hoststatus_i_id_idx on icinga_hoststatus(instance_id);
 CREATE INDEX servicestatus_i_id_idx on icinga_servicestatus(instance_id);
 CREATE INDEX contactstatus_i_id_idx on icinga_contactstatus(instance_id);
-CREATE INDEX timedeventqueue_i_id_idx on icinga_timedeventqueue(instance_id);
 CREATE INDEX comments_i_id_idx on icinga_comments(instance_id);
 CREATE INDEX scheduleddowntime_i_id_idx on icinga_scheduleddowntime(instance_id);
 CREATE INDEX runtimevariables_i_id_idx on icinga_runtimevariables(instance_id);
@@ -1514,18 +1450,6 @@ CREATE INDEX srvcstatus_latency_idx on icinga_servicestatus(latency);
 CREATE INDEX srvcstatus_ex_time_idx on icinga_servicestatus(execution_time);
 CREATE INDEX srvcstatus_sch_downt_d_idx on icinga_servicestatus(scheduled_downtime_depth);
 
--- timedeventqueue
-CREATE INDEX timed_e_q_event_type_idx on icinga_timedeventqueue(event_type);
-CREATE INDEX timed_e_q_sched_time_idx on icinga_timedeventqueue(scheduled_time);
-CREATE INDEX timed_e_q_object_id_idx on icinga_timedeventqueue(object_id);
-CREATE INDEX timed_e_q_rec_ev_id_idx on icinga_timedeventqueue(recurring_event);
-
--- timedevents
-CREATE INDEX timed_e_event_type_idx on icinga_timedevents(event_type);
--- CREATE INDEX timed_e_sched_time_idx on icinga_timedevents(scheduled_time); --already set for delete
-CREATE INDEX timed_e_object_id_idx on icinga_timedevents(object_id);
-CREATE INDEX timed_e_rec_ev_idx on icinga_timedevents(recurring_event);
-
 -- hostchecks
 CREATE INDEX hostchks_h_obj_id_idx on icinga_hostchecks(host_object_id);
 
@@ -1574,9 +1498,6 @@ CREATE INDEX statehist_i_id_o_id_s_ty_s_ti on icinga_statehistory(instance_id, o
 create index statehist_state_idx on icinga_statehistory(object_id,state);
 
 
--- SLA statehistory
-CREATE INDEX slahist_i_id_o_id_s_ti_s_s_ti_e on icinga_slahistory(instance_id,object_id,start_time,end_time);
-
 -- Icinga Web Notifications
 CREATE INDEX notification_idx ON icinga_notifications(notification_type, object_id, start_time);
 CREATE INDEX notification_object_id_idx ON icinga_notifications(object_id);
@@ -1605,6 +1526,6 @@ CREATE INDEX sla_idx_obj ON icinga_objects (objecttype_id, is_active, name1);
 -- -----------------------------------------
 -- set dbversion
 -- -----------------------------------------
-INSERT INTO icinga_dbversion (name, version, create_time, modify_time) VALUES ('idoutils', '1.9.0', NOW(), NOW()) ON DUPLICATE KEY UPDATE version='1.9.0', modify_time=NOW();
+INSERT INTO icinga_dbversion (name, version, create_time, modify_time) VALUES ('idoutils', '1.10.0', NOW(), NOW()) ON DUPLICATE KEY UPDATE version='1.10.0', modify_time=NOW();
 
 
