@@ -302,7 +302,7 @@ CREATE TABLE commenthistory (
 
 alter table commenthistory add constraint commenthist_pk PRIMARY KEY  (id)
 	using index tablespace &&IDXTBS;
-alter table commenthistory add constraint commenthist_uq  UNIQUE (instance_id,comment_time,internal_comment_id)
+alter table commenthistory add constraint commenthist_uq  UNIQUE (instance_id,object_id,comment_time,internal_comment_id)
 	using index tablespace &&IDXTBS;
 -- --------------------------------------------------------
 
@@ -330,7 +330,7 @@ CREATE TABLE comments (
 
 alter table comments add constraint comments_pk PRIMARY KEY  (id)
 	using index tablespace &&IDXTBS;
-alter table comments add constraint comments_uq  UNIQUE (instance_id,comment_time,internal_comment_id)
+alter table comments add constraint comments_uq  UNIQUE (instance_id,object_id,comment_time,internal_comment_id)
 	using index tablespace &&IDXTBS;
 	
 
@@ -1071,6 +1071,7 @@ CREATE TABLE hoststatus (
   output clob,
   long_output clob,
   perfdata clob,
+  check_source varchar2(255) default '',
   current_state integer default 0 ,
   has_been_checked integer default 0 ,
   should_be_scheduled integer default 0 ,
@@ -1155,7 +1156,8 @@ CREATE TABLE logentries (
   logentry_type integer default 0 ,
   logentry_data clob,
   realtime_data integer default 0 ,
-  inferred_data_extracted integer default 0 
+  inferred_data_extracted integer default 0 ,
+  object_id integer default NULL
 )
 lob (logentry_data) store as logentries_data_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
@@ -1614,6 +1616,7 @@ CREATE TABLE servicestatus (
   output clob,
   long_output clob,
   perfdata clob,
+  check_source varchar2(255) default '',
   current_state integer default 0 ,
   has_been_checked integer default 0 ,
   should_be_scheduled integer default 0 ,
@@ -1728,53 +1731,6 @@ alter table systemcommands add CONSTRAINT systemcommands_uq UNIQUE (instance_id,
 	using index tablespace &&IDXTBS;
 
 
--- --------------------------------------------------------
-
--- 
--- Table structure for table timedeventqueue
--- 
-
-CREATE TABLE timedeventqueue (
-  id integer ,
-  instance_id integer default 0 ,
-  event_type integer default 0 ,
-  queued_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  queued_time_usec integer default 0 ,
-  scheduled_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  recurring_event integer default 0 ,
-  object_id integer default 0 
-)tablespace &&DATATBS;
-alter table timedeventqueue add constraint timedeventqueue_pk PRIMARY KEY  (id)
-	using index tablespace &&IDXTBS;
-
-
-
--- --------------------------------------------------------
-
--- 
--- Table structure for table timedevents
--- 
-
-CREATE TABLE timedevents (
-  id integer ,
-  instance_id integer default 0 ,
-  event_type integer default 0 ,
-  queued_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  queued_time_usec integer default 0 ,
-  event_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  event_time_usec integer default 0 ,
-  scheduled_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  recurring_event integer default 0 ,
-  object_id integer default 0 ,
-  deletion_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  deletion_time_usec integer default 0 
-)tablespace &&DATATBS;
-alter table timedevents add constraint timedevents_pk PRIMARY KEY  (id)
-	using index tablespace &&IDXTBS;
-alter table timedevents add CONSTRAINT timedevents_uq UNIQUE (instance_id,event_type,scheduled_time,object_id)
-	using index tablespace &&IDXTBS;
-
-
 -- --------------------------------------------------------
 
 -- 
@@ -1812,28 +1768,6 @@ alter table timeperiods add CONSTRAINT timeperiods_uq UNIQUE (instance_id,config
 	using index tablespace &&IDXTBS;
 
 
--- --------------------------------------------------------
-
--- 
--- Table structure for table slahistory
--- 
-
-CREATE TABLE slahistory (
-  id integer ,
-  instance_id integer default 0 ,
-  start_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  end_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  acknowledgement_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  object_id integer default 0 ,
-  state integer default 0 ,
-  state_type integer default 0 ,
-  scheduled_downtime integer default 0
-)tablespace &&DATATBS;
-alter table slahistory add constraint slahistory_pk PRIMARY KEY  (id)
-	using index tablespace &&IDXTBS;
-
-
-
 -- -----------------------------------------
 -- add index (delete)
 -- -----------------------------------------
@@ -1845,8 +1779,6 @@ alter table slahistory add constraint slahistory_pk PRIMARY KEY  (id)
 -- EXTERNALCOMMANDS => entry_time
 
 -- instance_id
-CREATE INDEX timedevents_i_id_idx on timedevents(instance_id) tablespace &&IDXTBS;
-CREATE INDEX timedeventq_i_id_idx on timedeventqueue(instance_id) tablespace &&IDXTBS;
 CREATE INDEX systemcommands_i_id_idx on systemcommands(instance_id) tablespace &&IDXTBS;
 CREATE INDEX servicechecks_i_id_idx on servicechecks(instance_id)tablespace &&IDXTBS;
 CREATE INDEX hostchecks_i_id_idx on hostchecks(instance_id) tablespace &&IDXTBS;
@@ -1854,8 +1786,6 @@ CREATE INDEX eventhandlers_i_id_idx on eventhandlers(instance_id) tablespace &&I
 CREATE INDEX externalcommands_i_id_idx on externalcommands(instance_id) tablespace &&IDXTBS;
 
 -- time
-CREATE INDEX timedevents_time_id_idx on timedevents(scheduled_time) tablespace &&IDXTBS;
-CREATE INDEX timedeventq_time_id_idx on timedeventqueue(scheduled_time) tablespace &&IDXTBS;
 CREATE INDEX systemcommands_time_id_idx on systemcommands(start_time) tablespace &&IDXTBS;
 CREATE INDEX servicechecks_time_id_idx on servicechecks(start_time) tablespace &&IDXTBS;
 CREATE INDEX hostchecks_time_id_idx on hostchecks(start_time) tablespace &&IDXTBS;
@@ -1869,7 +1799,6 @@ CREATE INDEX externalcommands_time_id_idx on externalcommands(entry_time) tables
 CREATE INDEX hoststatus_i_id_idx on hoststatus(instance_id) tablespace &&IDXTBS;
 CREATE INDEX servicestatus_i_id_idx on servicestatus(instance_id) tablespace &&IDXTBS;
 CREATE INDEX contactstatus_i_id_idx on contactstatus(instance_id) tablespace &&IDXTBS;
--- CREATE INDEX timedeventqueue_i_id_idx on timedeventqueue(instance_id); -- defined adobe
 CREATE INDEX comments_i_id_idx on comments(instance_id) tablespace &&IDXTBS;
 CREATE INDEX scheduleddowntime_i_id_idx on scheduleddowntime(instance_id) tablespace &&IDXTBS;
 CREATE INDEX runtimevariables_i_id_idx on runtimevariables(instance_id) tablespace &&IDXTBS;
@@ -1953,18 +1882,6 @@ CREATE INDEX srvcstatus_latency_idx on servicestatus(latency) tablespace &&IDXTB
 CREATE INDEX srvcstatus_ex_time_idx on servicestatus(execution_time) tablespace &&IDXTBS;
 CREATE INDEX srvcstatus_sch_downt_d_idx on servicestatus(scheduled_downtime_depth) tablespace &&IDXTBS;
 
--- timedeventqueue
-CREATE INDEX timed_e_q_event_type_idx on timedeventqueue(event_type) tablespace &&IDXTBS;
--- CREATE INDEX timed_e_q_sched_time_idx on timedeventqueue(scheduled_time); -- defined above
-CREATE INDEX timed_e_q_object_id_idx on timedeventqueue(object_id) tablespace &&IDXTBS;
-CREATE INDEX timed_e_q_rec_ev_id_idx on timedeventqueue(recurring_event) tablespace &&IDXTBS;
-
--- timedevents
-CREATE INDEX timed_e_event_type_idx on timedevents(event_type) tablespace &&IDXTBS;
---CREATE INDEX timed_e_sched_time_idx on timedevents(scheduled_time); --already set for delete
-CREATE INDEX timed_e_object_id_idx on timedevents(object_id) tablespace &&IDXTBS;
-CREATE INDEX timed_e_rec_ev_idx on timedevents(recurring_event) tablespace &&IDXTBS;
-
 -- hostchecks
 CREATE INDEX hostchks_h_obj_id_idx on hostchecks(host_object_id) tablespace &&IDXTBS;
 
@@ -1987,10 +1904,6 @@ CREATE INDEX statehist_time_idx on statehistory(instance_id, object_id, state_ty
 create index statehistory_state_idx on statehistory(object_id,state)
 tablespace &&IDXTBS;
 
-
--- slahistory
-CREATE INDEX slahist_idx on slahistory(instance_id,object_id,start_time,end_time) tablespace &&IDXTBS;
-
 -- Icinga Web Notifications
 CREATE INDEX notification_idx ON notifications(notification_type, object_id, start_time) tablespace &&IDXTBS;
 CREATE INDEX notification_object_id_idx ON notifications(object_id) tablespace &&IDXTBS;
@@ -2289,16 +2202,6 @@ CREATE SEQUENCE seq_systemcommands
    increment by 1
    nocache nomaxvalue;
 
-CREATE SEQUENCE seq_timedeventqueue
-   start with 1
-   increment by 1
-   nocache nomaxvalue;
-
-CREATE SEQUENCE seq_timedevents
-   start with 1
-   increment by 1
-   nocache nomaxvalue;
-
 CREATE SEQUENCE seq_timep_timer
    start with 1
    increment by 1
