@@ -3,7 +3,7 @@
 #-- create_mysqldb.sh
 #-- DB definition for MySQL
 #--
-#-- Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
+#-- Copyright (c) 2009-2013 Icinga Development Team (http://www.icinga.org)
 #--
 #-- current version: 2011-05-03 Thomas Dressler
 #-- -- --------------------------------------------------------
@@ -25,7 +25,7 @@ cd ../mysql
 
 echo "Enter password for mysql user '$DBADMIN' or <enter> if none"
 read ROOTPASS
-if [ -n "ROOTPASS" ];then
+if [ -n "$ROOTPASS" ];then
 	P=-p$ROOTPASS
 fi
 echo "drop existing DB $DB and user $DBUSER..."
@@ -40,7 +40,7 @@ echo "create new DB $DB, user $DBUSER and objects..."
 mysql -u $DBADMIN -h $DBHOST $P --verbose >$WD/create_mysqldb.log mysql <<EOS2
  CREATE DATABASE $DB;
  CREATE USER '$DBUSER'@'$DBHOST'  IDENTIFIED BY '$DBPASS';
- GRANT USAGE ON *.* TO '$DBUSER'@'$DBHOST' WITH MAX_QUERIES_PER_HOUR 0 MAX_CONNECTIONS_PER_HOUR 0 MAX_UPDATES_PER_HOUR 0;
+ GRANT USAGE ON $DB.* TO '$DBUSER'@'$DBHOST' WITH MAX_QUERIES_PER_HOUR 0 MAX_CONNECTIONS_PER_HOUR 0 MAX_UPDATES_PER_HOUR 0;
  GRANT SELECT , INSERT , UPDATE , DELETE ON $DB.* to '$DBUSER'@'$DBHOST';
  FLUSH PRIVILEGES ;
  use $DB;
