@@ -134,6 +134,7 @@ int grab_service_macros(service *svc) {}
 int grab_service_macros_r(icinga_macros *mac, service *svc) {}
 
 void broker_log_data(int a, int b, int c, char *d, unsigned long e, time_t f, struct timeval *g) {}
+void broker_log_data_with_host_service(int a, int b, int c, char *d, unsigned long e, time_t f, struct timeval *g, host *hst, service *svc) {}
 
 int clear_volatile_macros_r(icinga_macros *mac) {}
 int clear_service_macros_r(icinga_macros *mac) {}
@@ -221,9 +222,6 @@ int             enable_predictive_host_dependency_checks = DEFAULT_ENABLE_PREDIC
 int      stalking_event_handlers_for_hosts;
 int      stalking_event_handlers_for_services;
 
-int	event_profiling_enabled = FALSE;
-void 	profiler_update(int event, struct timeval start) {}
-
 int has_shell_metachars(const char *s) {}
 
 void remove_host_acknowledgement(host * hst) {}
