@@ -296,7 +296,9 @@ int log_debug_info(int level, int verbosity, const char *fmt, ...) {
 	va_end(ap);
 }
 int close_log_file(void) {}
+int log_level(int level, int verbosity) {}
 int chown_debug_log(uid_t uid, gid_t gid) {}
+int fix_log_file_owner(uid_t uid, gid_t gid) {}
 
 int neb_free_callback_list(void) {}
 void broker_program_status(int type, int flags, int attr, struct timeval *timestamp) {}
@@ -326,9 +328,7 @@ int service_notification(service *svc, int type, char *not_author, char *not_dat
 
 
 /* Icinga special */
-int     event_profiling_enabled = FALSE;
 unsigned long max_check_result_list_items = DEFAULT_MAX_CHECK_RESULT_LIST_ITEMS;
-void    profiler_update(int event, struct timeval start) {}
 
 void remove_host_acknowledgement(host * hst) {}
 void remove_service_acknowledgement(service * svc) {}
